@@ -6,7 +6,7 @@ class HeartbeatLog:
     """
     def __init__(self, name, interval_env):
         self._name = name
-        if not interval_env is not None and interval_env.isdigit():     # Note, interval_env must be positive integer number!
+        if interval_env is not None and interval_env.isdigit():     # Note, interval_env must be positive integer number!
             self._interval_val = int(interval_env)
         else:
             self._interval_val = 1
